@@ -1,3 +1,7 @@
+pub mod message;
+
 pub mod component;
 pub mod console_component;
 pub mod file_component;
+
+pub mod logger;
